/* Panels */
.panel {
    border: 1px solid grey;
    border-radius: 4px;
    margin-bottom: 0.85em;
}

/* Panel header */
.panel .panel-header {
    display: block;
    clear: both;
    padding: 10px 15px;
    border-bottom: 1px solid;
    border-bottom-color: currentcolor;
    border-top-left-radius: 3px;
    border-top-right-radius: 3px;
}

.panel .panel-header p {
    font-weight: 700;
    margin: 0;
}

.panel .panel-header p:after {
    font-size: 0.75em;
    font-weight: 200;
    text-align: right;
    float: right;
}

.panel .panel-header p:after {
    content: "Click to expand";
}

.panel .panel-header.open p:after {
    content: "";
}

/* Panel body */
.panel .panel-body {
    padding: 15px;
    display: block;
}

/* Prereq panel */
.panel-prereq {
    border-color: #faebcc;
}

.panel-prereq .panel-header {
    color: #8a6d3b;
    background-color: #fcf8e3;
    border-color: #faebcc;
}

/* Callout panel */
.panel-callout {
    border-color: #337ab7;
}

.panel-callout .panel-header {
    color: #fff;
    background-color: #337ab7;
    border-color: #337ab7;
}

/* Challenge panel */
.panel-challenge {
    border-color: #d6e9c6;
}

.panel-challenge .panel-header {
    color: #3c763d;
    background-color: #dff0d8;
    border-color: #d6e9c6;
}

/* Hiddenchallenge panel */
.panel-hiddenchallenge {
    border-color: #d6e9c6;
}

.panel-hiddenchallenge .panel-header {
    color: #3c763d;
    background-color: #dff0d8;
    border-color: #d6e9c6;
}

/* Solution panel */
.panel-solution {
    border-color: #ebccd1;
}

.panel-solution .panel-header {
    color: #a94442;
    background-color: #f2dede;
    border-color: #ebccd1;
}

/* Objectives panel */
.panel-objectives {
    border-color: #faebcc;
}

.panel-objectives .panel-header {
    color: #8a6d3b;
    background-color: #fcf8e3;
    border-color: #faebcc;
}

/* Keypoints panel */
.panel-keypoints {
    border-color: #d6e9c6;
}

.panel-keypoints .panel-header {
    color: #3c763d;
    background-color: #dff0d8;
    border-color: #d6e9c6;
}

/* Discussion panel */
.panel-discussion {
    border-color: #bce8f1;
}

.panel-discussion .panel-header {
    color: #31708f;
    background-color: #d9edf7;
    border-color: #bce8f1;
}
